<?php

namespace Drupal\synmail\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements the form settings controller.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'synmail_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['synmail.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('synmail.settings');

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General settings'),
      '#open' => TRUE,
    ];

    $form["general"]['phpmail'] = [
      '#title' => $this->t('Rewrite phpmail'),
      '#type' => 'checkbox',
      '#maxlength' => 20,
      '#required' => FALSE,
      '#size' => 15,
      '#default_value' => $config->get('phpmail'),
      '#description' => $this->t('Better works with non-latin "From" (Recommended).'),
    ];
    $form['general']['from'] = [
      '#title' => $this->t('From Header'),
      '#default_value' => $config->get('from'),
      '#type' => 'textfield',
      '#description' => $this->t('Mail from,
        ex.: <i>MySite @example</i>', ['@example' => '<webmaster@example.com>']),
    ];

    $form["general"]['debug'] = [
      '#title' => $this->t('Debug mode'),
      '#type' => 'checkbox',
      '#maxlength' => 20,
      '#required' => FALSE,
      '#size' => 15,
      '#default_value' => $config->get('debug'),
      '#description' => $this->t('Display full sendmail information with dsm().'),
    ];
    $form['contact'] = [
      '#type' => 'details',
      '#title' => $this->t('Contact Form'),
      '#open' => TRUE,
    ];
    $form['contact']['emails'] = [
      '#title' => $this->t('Contact form Recipients'),
      '#default_value' => $config->get('emails'),
      '#description' => $this->t('1 email per line.'),
      '#type' => 'textarea',
    ];
    $form["contact"]['tpl'] = [
      '#title' => $this->t('Rewrite submission template'),
      '#description' => $this->t('Module template looks good.'),
      '#type' => 'checkbox',
      '#maxlength' => 20,
      '#required' => FALSE,
      '#size' => 15,
      '#default_value' => $config->get('tpl'),
    ];
    $form["contact"]['html'] = [
      '#title' => $this->t('Send html instead txt'),
      '#type' => 'checkbox',
      '#maxlength' => 20,
      '#required' => FALSE,
      '#size' => 15,
      '#default_value' => $config->get('html'),
      '#description' => $this->t('Add text/html header.'),
    ];
    $form["contact"]['header'] = [
      '#title' => $this->t('Mail extra information'),
      '#default_value' => $config->get('header'),
      '#description' => $this->t('Message before submission.'),
      '#type' => 'textarea',
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('synmail.settings');
    $config
      ->set('phpmail', $form_state->getValue('phpmail'))
      ->set('from', $form_state->getValue('from'))
      ->set('debug', $form_state->getValue('debug'))
      ->set('emails', $form_state->getValue('emails'))
      ->set('tpl', $form_state->getValue('tpl'))
      ->set('html', $form_state->getValue('html'))
      ->set('header', $form_state->getValue('header'))
      ->save();
  }

}
